@@ -27,7 +27,10 @@ CARBON_SUFFIX = "carbon_suffix"
 
 DATA_SECTION = "data"
 LOG_FILE = "log_file"
+FOLLOW_DATA_FILE = "follow"
+FOLLOW_INTERVAL_SECONDS = "follow_interval_seconds"
 
 GRINDER_SECTION="grinder"
 TIME_GROUP_MILLISECONDS = "time_group_milliseconds"
 GRINDER_MAPPING_FILE = "grinder_mapping_file"
+RESUME = "resume"
\ No newline at end of file
